# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aiges/aiges_inner/aiges_inner.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#aiges/aiges_inner/aiges_inner.proto\x12\x05\x61iges\"\x12\n\x03Ret\x12\x0b\n\x03ret\x18\x01 \x01(\x05\"\x1a\n\x05SvcId\x12\x11\n\tserviceId\x18\x01 \x01(\t\"\x16\n\x06Schema\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\xac\x01\n\x0bRequestData\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\x0c\n\x04type\x18\x03 \x01(\r\x12\x0e\n\x06status\x18\x04 \x01(\r\x12*\n\x04\x64\x65sc\x18\x05 \x03(\x0b\x32\x1c.aiges.RequestData.DescEntry\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x1a+\n\tDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xae\x01\n\x0cResponseData\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\x0c\n\x04type\x18\x03 \x01(\r\x12\x0e\n\x06status\x18\x04 \x01(\r\x12+\n\x04\x64\x65sc\x18\x05 \x03(\x0b\x32\x1d.aiges.ResponseData.DescEntry\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x1a+\n\tDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n\x08Response\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0b\n\x03ret\x18\x02 \x01(\x05\x12!\n\x04list\x18\x03 \x03(\x0b\x32\x13.aiges.ResponseData\"l\n\x0bInitRequest\x12.\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x1e.aiges.InitRequest.ConfigEntry\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x01\n\x07Request\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12*\n\x06params\x18\x02 \x03(\x0b\x32\x1a.aiges.Request.ParamsEntry\x12 \n\x04list\x18\x03 \x03(\x0b\x32\x12.aiges.RequestData\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1d\n\rStreamRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t2\x98\x02\n\x0eWrapperService\x12/\n\x0bwrapperInit\x12\x12.aiges.InitRequest\x1a\n.aiges.Ret\"\x00\x12\x34\n\x0fwrapperOnceExec\x12\x0e.aiges.Request\x1a\x0f.aiges.Response\"\x00\x12.\n\rwrapperSchema\x12\x0c.aiges.SvcId\x1a\r.aiges.Schema\"\x00\x12\x39\n\ntestStream\x12\x14.aiges.StreamRequest\x1a\x0f.aiges.Response\"\x00(\x01\x30\x01\x12\x34\n\x0b\x63ommunicate\x12\x0e.aiges.Request\x1a\x0f.aiges.Response\"\x00(\x01\x30\x01\x42\tZ\x07./protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aiges.aiges_inner.aiges_inner_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\007./proto'
  _REQUESTDATA_DESCENTRY._options = None
  _REQUESTDATA_DESCENTRY._serialized_options = b'8\001'
  _RESPONSEDATA_DESCENTRY._options = None
  _RESPONSEDATA_DESCENTRY._serialized_options = b'8\001'
  _INITREQUEST_CONFIGENTRY._options = None
  _INITREQUEST_CONFIGENTRY._serialized_options = b'8\001'
  _REQUEST_PARAMSENTRY._options = None
  _REQUEST_PARAMSENTRY._serialized_options = b'8\001'
  _RET._serialized_start=46
  _RET._serialized_end=64
  _SVCID._serialized_start=66
  _SVCID._serialized_end=92
  _SCHEMA._serialized_start=94
  _SCHEMA._serialized_end=116
  _REQUESTDATA._serialized_start=119
  _REQUESTDATA._serialized_end=291
  _REQUESTDATA_DESCENTRY._serialized_start=248
  _REQUESTDATA_DESCENTRY._serialized_end=291
  _RESPONSEDATA._serialized_start=294
  _RESPONSEDATA._serialized_end=468
  _RESPONSEDATA_DESCENTRY._serialized_start=248
  _RESPONSEDATA_DESCENTRY._serialized_end=291
  _RESPONSE._serialized_start=470
  _RESPONSE._serialized_end=541
  _INITREQUEST._serialized_start=543
  _INITREQUEST._serialized_end=651
  _INITREQUEST_CONFIGENTRY._serialized_start=606
  _INITREQUEST_CONFIGENTRY._serialized_end=651
  _REQUEST._serialized_start=654
  _REQUEST._serialized_end=801
  _REQUEST_PARAMSENTRY._serialized_start=756
  _REQUEST_PARAMSENTRY._serialized_end=801
  _STREAMREQUEST._serialized_start=803
  _STREAMREQUEST._serialized_end=832
  _WRAPPERSERVICE._serialized_start=835
  _WRAPPERSERVICE._serialized_end=1115
# @@protoc_insertion_point(module_scope)
